.:TSETMC:. :: تعدیل قیمت

PSB is being developed by Pooya Paridel.
شركت مديريت فناوري بورس تهران
Tehran Securities Exchange Technology Management Co
تعدیل قیمت
دریافت فایل اکسل

نماد | نام | تاریخ | تعدیل شده | قبل از تعدیل
--- | --- | --- | --- | ---
جو9606-09 | جودامي 9606انباركشت وصنعت مغان | 1396/3/24 | 8,800 | 8,800
ذرت9512-46 | ذرت دانه اي 9512 انبار سبيلي | 1395/9/24 | 10,368 | 7,000
ذرت9512-27 | ذرت9512سيلوي شاداب دانه جنوب | 1395/9/24 | 7,800 | 7,400
ذرت9512-47 | ذرت دانه اي 9512 انبار بنوت | 1395/9/24 | 10,368 | 7,004
عذوب1 | سلف تيرآهن14 ذوب آهن مرحله اول | 1395/2/4 | 13,500 | 1,386,579
عپيويسي1 | اوراق سلف استاندارد پي وي سي | 1394/8/9 | 26,316 | 1,000